<h1>Project Description</h1>
<p align="center">
  <img src="https://img.shields.io/badge/Version-0.0.8-orange?style=for-the-badge">
  <img src="https://img.shields.io/github/license/Aru-Ofc-git/CIRCLE_TOOLS?style=for-the-badge">
</p>
<p align="center">
  <img src="https://img.shields.io/badge/Author-ARU-green?style=flat-square">
  <img src="https://img.shields.io/badge/Open%20Source-Yes-green?style=flat-square">
  <img src="https://img.shields.io/badge/Written%20In-Python-green?style=flat-square">
</p>
 
<br>
<h2>Circlerobi</h2>
<br>
<p><b>circlerobi </b>is a simple ROBI CIRCLE PROJECT. </p>

<h1>Installation</h1>

```
$ pip install circlerobi
```

<h1>import</h1>

```python
from circle import robicircle
```


<h1> USE </h1>

<h4> Circle Id to number </h4>

```python
robicircle.idtonumber('Your Circle ID')
```
<h4> Example </h4>

```python
from circle import robicircle
robicircle.idtonumber('Your Circle ID')
```

<img src="idtoNum.png" alt="">



<h4> Circle Id to number </h4>

```python
robicircle.idtonumber('Your Circle ID')
```

<h4> Number To id </h4>

```python
from circle import robicircle
robicircle.numbertoid('018XXXXXXXX')
```

<img src="numbertoid.png" alt="">

<p align="center">
  <b>For More Visit GitHub</b>
  <br>
  <a href="https://github.com/Aru-Ofc-git" target="_blank"><img src="https://img.shields.io/badge/GitHub-171515.svg?&style=flat-square&logo=github&logoColor=white" alt="Github"></a>
  </p>


<p align="center">

    `` 📡 Get in Touch `` 
<br>

<a href="https://www.facebook.com/Aru.Ofc" target="_blank"><img src="https://img.shields.io/badge/FACEBOOK-4267B2.svg?&style=flat-square&logo=facebook&logoColor=white" alt="LinkedIn"></a>
<a href="https://www.instagram.com/Aru.Ofc.Ins" target="_blank"><img src="https://img.shields.io/badge/Instagram-%23E4405F.svg?&style=flat-square&logo=instagram&logoColor=white" alt="Instagram"></a>
<a href="https://twitter.com/aru_ofc_twiter" target="_blank"><img src="https://img.shields.io/badge/Twitter-%231DA1F2.svg?&style=flat-square&logo=twitter&logoColor=white" alt="Twitter"></a>
<a href="https://open.spotify.com/user/rwvotqr02yuzpyfmkkri3b5k1?si=X4sohjMTTCmIMuniDJ5ECA&utm_source=copy-link" target="_blank"><img src="https://img.shields.io/badge/Spotify-%231ED760.svg?&style=flat-square&logo=spotify&logoColor=white" alt="Spotify"></a>
<a href="https://www.youtube.com/c/ARULyrics1" target="_blank"><img src="https://img.shields.io/badge/YouTube-FF0000.svg?&style=flat-square&logo=youtube&logoColor=white" alt="YouTube"></a>
<a href="https://dev.to/aruofc" target="_blank"><img src="https://img.shields.io/badge/DEV-%230A0A0A.svg?&style=flat-square&logo=DEV.to&logoColor=white" alt="DEV.to"></a>
<a href="mailto: arifulislam275m.com" target="_blank"><img src="https://img.shields.io/badge/Email-BB001B.svg?&style=flat-square&logo=gmail&logoColor=white" alt="Gmail"></a>
<a href="https://github.com/Aru-Ofc-git" target="_blank"><img src="https://img.shields.io/badge/GitHub-171515.svg?&style=flat-square&logo=github&logoColor=white" alt="Github"></a>
 
<br>
 <br>
  <b align="center">Made With ❤️ by <a href="https://www.facebook.com/Siillent.Killer.Arman">ARU</a> </b>
</p>


